===============
django-disguise
===============

.. image:: https://travis-ci.org/marazmiki/django-disguise.svg?branch=master
     :target: https://travis-ci.org/marazmiki/django-disguise
     :alt: Travis CI building status

.. image:: https://coveralls.io/repos/github/marazmiki/django-disguise/badge.svg?branch=master
     :target: https://coveralls.io/github/marazmiki/django-disguise?branch=master
     :alt: Code coverage status

.. image:: https://badge.fury.io/py/django-disguise.svg
     :target: http://badge.fury.io/py/django-disguise
     :alt: PyPI release

.. image:: https://pypip.in/wheel/django-disguise/badge.svg
     :target: https://pypi.python.org/pypi/django-disguise/
     :alt: Wheel Status

.. image:: https://img.shields.io/pypi/pyversions/django-disguise.svg
     :target: https://img.shields.io/pypi/pyversions/django-disguise.svg
     :alt: Supported Python versions

.. image:: https://img.shields.io/pypi/djversions/django-disguise.svg
     :target: https://pypi.python.org/pypi/django-disguise/
     :alt: Supported Django versions

.. image:: https://readthedocs.org/projects/django-disguise/badge/?version=latest
     :target: https://django-disguise.readthedocs.io/en/latest/?badge=latest
     :alt: Documentation Status

This application allows a site superuser (or some staff user authorized for
the action) to *disguise* into an arbitrary user without knowing its password and without losing the original session.

* See the full documentation on `RTFD <https://django-disguise.readthedocs.io/latest/>`_.
* Look it in action on the `DEMO site <https://django-disguise.herokuapp.com>`_.
